==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/azurearcdata/kotlin/inputs/SqlServerDatabaseResourcePropertiesDatabaseOptionsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.azurearcdata.kotlin.inputs

import com.pulumi.azurenative.azurearcdata.inputs.SqlServerDatabaseResourcePropertiesDatabaseOptionsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * List of features that are enabled for the database
 * @property isAutoCloseOn
 * @property isAutoCreateStatsOn
 * @property isAutoShrinkOn
 * @property isAutoUpdateStatsOn
 * @property isEncrypted
 * @property isMemoryOptimizationEnabled
 * @property isRemoteDataArchiveEnabled
 * @property isTrustworthyOn
 */
public data class SqlServerDatabaseResourcePropertiesDatabaseOptionsArgs(
    public val isAutoCloseOn: Output<Boolean>? = null,
    public val isAutoCreateStatsOn: Output<Boolean>? = null,
    public val isAutoShrinkOn: Output<Boolean>? = null,
    public val isAutoUpdateStatsOn: Output<Boolean>? = null,
    public val isEncrypted: Output<Boolean>? = null,
    public val isMemoryOptimizationEnabled: Output<Boolean>? = null,
    public val isRemoteDataArchiveEnabled: Output<Boolean>? = null,
    public val isTrustworthyOn: Output<Boolean>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.azurearcdata.inputs.SqlServerDatabaseResourcePropertiesDatabaseOptionsArgs> {
    override fun toJava():
        com.pulumi.azurenative.azurearcdata.inputs.SqlServerDatabaseResourcePropertiesDatabaseOptionsArgs =
        com.pulumi.azurenative.azurearcdata.inputs.SqlServerDatabaseResourcePropertiesDatabaseOptionsArgs.builder()
            .isAutoCloseOn(isAutoCloseOn?.applyValue({ args0 -> args0 }))
            .isAutoCreateStatsOn(isAutoCreateStatsOn?.applyValue({ args0 -> args0 }))
            .isAutoShrinkOn(isAutoShrinkOn?.applyValue({ args0 -> args0 }))
            .isAutoUpdateStatsOn(isAutoUpdateStatsOn?.applyValue({ args0 -> args0 }))
            .isEncrypted(isEncrypted?.applyValue({ args0 -> args0 }))
            .isMemoryOptimizationEnabled(isMemoryOptimizationEnabled?.applyValue({ args0 -> args0 }))
            .isRemoteDataArchiveEnabled(isRemoteDataArchiveEnabled?.applyValue({ args0 -> args0 }))
            .isTrustworthyOn(isTrustworthyOn?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [SqlServerDatabaseResourcePropertiesDatabaseOptionsArgs].
 */
@PulumiTagMarker
public class SqlServerDatabaseResourcePropertiesDatabaseOptionsArgsBuilder internal constructor() {
    private var isAutoCloseOn: Output<Boolean>? = null

    private var isAutoCreateStatsOn: Output<Boolean>? = null

    private var isAutoShrinkOn: Output<Boolean>? = null

    private var isAutoUpdateStatsOn: Output<Boolean>? = null

    private var isEncrypted: Output<Boolean>? = null

    private var isMemoryOptimizationEnabled: Output<Boolean>? = null

    private var isRemoteDataArchiveEnabled: Output<Boolean>? = null

    private var isTrustworthyOn: Output<Boolean>? = null

    /**
     * @param value
     */
    @JvmName("vyjhoookmmvoafdj")
    public suspend fun isAutoCloseOn(`value`: Output<Boolean>) {
        this.isAutoCloseOn = value
    }

    /**
     * @param value
     */
    @JvmName("eidicfixhxcgghks")
    public suspend fun isAutoCreateStatsOn(`value`: Output<Boolean>) {
        this.isAutoCreateStatsOn = value
    }

    /**
     * @param value
     */
    @JvmName("vepxfypisnmpeqak")
    public suspend fun isAutoShrinkOn(`value`: Output<Boolean>) {
        this.isAutoShrinkOn = value
    }

    /**
     * @param value
     */
    @JvmName("misvrvbnqqpbbjhp")
    public suspend fun isAutoUpdateStatsOn(`value`: Output<Boolean>) {
        this.isAutoUpdateStatsOn = value
    }

    /**
     * @param value
     */
    @JvmName("yjbthklaojpqeptm")
    public suspend fun isEncrypted(`value`: Output<Boolean>) {
        this.isEncrypted = value
    }

    /**
     * @param value
     */
    @JvmName("brpdknmxvpcucfxb")
    public suspend fun isMemoryOptimizationEnabled(`value`: Output<Boolean>) {
        this.isMemoryOptimizationEnabled = value
    }

    /**
     * @param value
     */
    @JvmName("myoshfgqawlpxdqs")
    public suspend fun isRemoteDataArchiveEnabled(`value`: Output<Boolean>) {
        this.isRemoteDataArchiveEnabled = value
    }

    /**
     * @param value
     */
    @JvmName("dnagcbvaxnpngpid")
    public suspend fun isTrustworthyOn(`value`: Output<Boolean>) {
        this.isTrustworthyOn = value
    }

    /**
     * @param value
     */
    @JvmName("gifhcbttwuwsgoib")
    public suspend fun isAutoCloseOn(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.isAutoCloseOn = mapped
    }

    /**
     * @param value
     */
    @JvmName("cibsejttyvhujyyx")
    public suspend fun isAutoCreateStatsOn(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.isAutoCreateStatsOn = mapped
    }

    /**
     * @param value
     */
    @JvmName("klrsqqqtovimigqy")
    public suspend fun isAutoShrinkOn(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.isAutoShrinkOn = mapped
    }

    /**
     * @param value
     */
    @JvmName("vmxfllvxscfyqbno")
    public suspend fun isAutoUpdateStatsOn(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.isAutoUpdateStatsOn = mapped
    }

    /**
     * @param value
     */
    @JvmName("urlukacmiofxtarg")
    public suspend fun isEncrypted(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.isEncrypted = mapped
    }

    /**
     * @param value
     */
    @JvmName("llholuicjrmfigun")
    public suspend fun isMemoryOptimizationEnabled(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.isMemoryOptimizationEnabled = mapped
    }

    /**
     * @param value
     */
    @JvmName("xhhuovdxttdsupph")
    public suspend fun isRemoteDataArchiveEnabled(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.isRemoteDataArchiveEnabled = mapped
    }

    /**
     * @param value
     */
    @JvmName("kcwrmevurxtygnqv")
    public suspend fun isTrustworthyOn(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.isTrustworthyOn = mapped
    }

    internal fun build(): SqlServerDatabaseResourcePropertiesDatabaseOptionsArgs =
        SqlServerDatabaseResourcePropertiesDatabaseOptionsArgs(
            isAutoCloseOn = isAutoCloseOn,
            isAutoCreateStatsOn = isAutoCreateStatsOn,
            isAutoShrinkOn = isAutoShrinkOn,
            isAutoUpdateStatsOn = isAutoUpdateStatsOn,
            isEncrypted = isEncrypted,
            isMemoryOptimizationEnabled = isMemoryOptimizationEnabled,
            isRemoteDataArchiveEnabled = isRemoteDataArchiveEnabled,
            isTrustworthyOn = isTrustworthyOn,
        )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/azurearcdata/kotlin/inputs/SqlServerDatabaseResourcePropertiesDatabaseOptionsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.azurearcdata.kotlin.inputs

import com.pulumi.azurenative.azurearcdata.inputs.SqlServerDatabaseResourcePropertiesDatabaseOptionsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * List of features that are enabled for the database
 * @property isAutoCloseOn
 * @property isAutoCreateStatsOn
 * @property isAutoShrinkOn
 * @property isAutoUpdateStatsOn
 * @property isEncrypted
 * @property isMemoryOptimizationEnabled
 * @property isRemoteDataArchiveEnabled
 * @property isTrustworthyOn
 */
public data class SqlServerDatabaseResourcePropertiesDatabaseOptionsArgs(
    public val isAutoCloseOn: Output<Boolean>? = null,
    public val isAutoCreateStatsOn: Output<Boolean>? = null,
    public val isAutoShrinkOn: Output<Boolean>? = null,
    public val isAutoUpdateStatsOn: Output<Boolean>? = null,
    public val isEncrypted: Output<Boolean>? = null,
    public val isMemoryOptimizationEnabled: Output<Boolean>? = null,
    public val isRemoteDataArchiveEnabled: Output<Boolean>? = null,
    public val isTrustworthyOn: Output<Boolean>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.azurearcdata.inputs.SqlServerDatabaseResourcePropertiesDatabaseOptionsArgs> {
    override fun toJava():
        com.pulumi.azurenative.azurearcdata.inputs.SqlServerDatabaseResourcePropertiesDatabaseOptionsArgs =
        com.pulumi.azurenative.azurearcdata.inputs.SqlServerDatabaseResourcePropertiesDatabaseOptionsArgs.builder()
            .isAutoCloseOn(isAutoCloseOn?.applyValue({ args0 -> args0 }))
            .isAutoCreateStatsOn(isAutoCreateStatsOn?.applyValue({ args0 -> args0 }))
            .isAutoShrinkOn(isAutoShrinkOn?.applyValue({ args0 -> args0 }))
            .isAutoUpdateStatsOn(isAutoUpdateStatsOn?.applyValue({ args0 -> args0 }))
            .isEncrypted(isEncrypted?.applyValue({ args0 -> args0 }))
            .isMemoryOptimizationEnabled(isMemoryOptimizationEnabled?.applyValue({ args0 -> args0 }))
            .isRemoteDataArchiveEnabled(isRemoteDataArchiveEnabled?.applyValue({ args0 -> args0 }))
            .isTrustworthyOn(isTrustworthyOn?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [SqlServerDatabaseResourcePropertiesDatabaseOptionsArgs].
 */
@PulumiTagMarker
public class SqlServerDatabaseResourcePropertiesDatabaseOptionsArgsBuilder internal constructor() {
    private var isAutoCloseOn: Output<Boolean>? = null

    private var isAutoCreateStatsOn: Output<Boolean>? = null

    private var isAutoShrinkOn: Output<Boolean>? = null

    private var isAutoUpdateStatsOn: Output<Boolean>? = null

    private var isEncrypted: Output<Boolean>? = null

    private var isMemoryOptimizationEnabled: Output<Boolean>? = null

    private var isRemoteDataArchiveEnabled: Output<Boolean>? = null

    private var isTrustworthyOn: Output<Boolean>? = null

    /**
     * @param value
     */
    @JvmName("okmgtwaqkydwipum")
    public suspend fun isAutoCloseOn(`value`: Output<Boolean>) {
        this.isAutoCloseOn = value
    }

    /**
     * @param value
     */
    @JvmName("wxwdpwisjoelekjc")
    public suspend fun isAutoCreateStatsOn(`value`: Output<Boolean>) {
        this.isAutoCreateStatsOn = value
    }

    /**
     * @param value
     */
    @JvmName("dwmyujiayqsluyax")
    public suspend fun isAutoShrinkOn(`value`: Output<Boolean>) {
        this.isAutoShrinkOn = value
    }

    /**
     * @param value
     */
    @JvmName("uvibqdbeleaudhjt")
    public suspend fun isAutoUpdateStatsOn(`value`: Output<Boolean>) {
        this.isAutoUpdateStatsOn = value
    }

    /**
     * @param value
     */
    @JvmName("ruvjoyixshhulqyq")
    public suspend fun isEncrypted(`value`: Output<Boolean>) {
        this.isEncrypted = value
    }

    /**
     * @param value
     */
    @JvmName("ijfeylvlouedafdq")
    public suspend fun isMemoryOptimizationEnabled(`value`: Output<Boolean>) {
        this.isMemoryOptimizationEnabled = value
    }

    /**
     * @param value
     */
    @JvmName("rpjpgwrdoahixsmh")
    public suspend fun isRemoteDataArchiveEnabled(`value`: Output<Boolean>) {
        this.isRemoteDataArchiveEnabled = value
    }

    /**
     * @param value
     */
    @JvmName("ujpaawnjgbnqolto")
    public suspend fun isTrustworthyOn(`value`: Output<Boolean>) {
        this.isTrustworthyOn = value
    }

    /**
     * @param value
     */
    @JvmName("ipaewbyddrldsbre")
    public suspend fun isAutoCloseOn(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.isAutoCloseOn = mapped
    }

    /**
     * @param value
     */
    @JvmName("hluosfcbchxrkyhg")
    public suspend fun isAutoCreateStatsOn(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.isAutoCreateStatsOn = mapped
    }

    /**
     * @param value
     */
    @JvmName("jvgipfupybbbhhqa")
    public suspend fun isAutoShrinkOn(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.isAutoShrinkOn = mapped
    }

    /**
     * @param value
     */
    @JvmName("uvbrwmeyfwpmnrqt")
    public suspend fun isAutoUpdateStatsOn(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.isAutoUpdateStatsOn = mapped
    }

    /**
     * @param value
     */
    @JvmName("stittgmmviowinya")
    public suspend fun isEncrypted(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.isEncrypted = mapped
    }

    /**
     * @param value
     */
    @JvmName("smtjaouftbiqikiw")
    public suspend fun isMemoryOptimizationEnabled(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.isMemoryOptimizationEnabled = mapped
    }

    /**
     * @param value
     */
    @JvmName("leehhocysolmhopi")
    public suspend fun isRemoteDataArchiveEnabled(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.isRemoteDataArchiveEnabled = mapped
    }

    /**
     * @param value
     */
    @JvmName("pnwccrkyefpeflnc")
    public suspend fun isTrustworthyOn(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.isTrustworthyOn = mapped
    }

    internal fun build(): SqlServerDatabaseResourcePropertiesDatabaseOptionsArgs =
        SqlServerDatabaseResourcePropertiesDatabaseOptionsArgs(
            isAutoCloseOn = isAutoCloseOn,
            isAutoCreateStatsOn = isAutoCreateStatsOn,
            isAutoShrinkOn = isAutoShrinkOn,
            isAutoUpdateStatsOn = isAutoUpdateStatsOn,
            isEncrypted = isEncrypted,
            isMemoryOptimizationEnabled = isMemoryOptimizationEnabled,
            isRemoteDataArchiveEnabled = isRemoteDataArchiveEnabled,
            isTrustworthyOn = isTrustworthyOn,
        )
}
